@@ -52,26 +52,52 @@ int UseGrStyle(const char ReqFlag)
 
 
 /** Get character froom User Character Set */
-const char *UserCharSet(WORD char_code, TconvertedPass1 *cq)
+WORD UserCharSet(unsigned char char_code, TconvertedPass1 *cq)
 {
   if(UserWPCharSet==NULL)
-	   {
-NoUserChar:cq->perc.Hide();
-	   fprintf(cq->err, _("\nWarning: Please add user character No:%d into external config file!"),(int)char_code);
-	   UnknownCharacters++;
-	   return "Usr?";
-	   }
-  if(UserWPCharSet[char_code]==NULL) goto NoUserChar;
-  return(UserWPCharSet[char_code]);
+	{
+	if(cq->err)
+	  {         
+	  cq->perc.Hide();
+	  fprintf(cq->err, _("\nWarning: Please define /CurrentFontSet for user symbol %u!"), (unsigned)char_code);
+	  }
+	UnknownCharacters++;
+	return 0xFFFF;
+	}
+  return (*UserWPCharSet)[char_code];
 }
 
 
-/** Return unicode character packed in ascii. */
+
+/** Return unicode character packed in ASCII. */
 const char *ExpandUTF8(WORD wchar)
 {
-static char buffer[17];
-  sprintf(buffer,"\\unichar{\"%4.4X\"}", wchar);
+static char buffer[4];
+  if(wchar<=0x7F)
+  {
+    buffer[0] = wchar;
+    buffer[1] = 0;
+    return buffer;
+  }
+
+  if(wchar<=0x7FF)
+  {
+    buffer[0] = 0xC0 | (wchar>>6);
+    buffer[1] = 0x80 | (wchar & 0x3F);
+    buffer[2] = 0;
+    return buffer;
+  }
+
+  buffer[0] = 0xC8 | (wchar>>12);
+  buffer[1] = 0x80 | ((wchar>>6) & 0x3F);
+  buffer[2] = 0x80 | (wchar & 0x3F);
+  buffer[3] = 0;
   return buffer;
+
+//static char buffer[17];
+// sprintf(buffer,"\\unichar{\"%4.4X\"}", wchar);
+// sprintf(buffer,"\\symbol{\"%4.4X}", wchar);
+// return buffer;
 }
 
 
