@@ -1089,9 +1089,10 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
   string Numeral;
 
   if(seq==NULL) return;
-  if(strE[0] != '_' && strE[0] != '^') strE=' '+strE;
+  if(strE[0]!='_' && strE[0]!='^' && strE[0]!='}')
+      strE=' '+strE;
 
-  p=0;
+  p = 0;
   while(*seq!=0)
     {
     switch(*seq)
@@ -1447,7 +1448,7 @@ BYTE styles;
   StrBeg.trim();
   if(((length(StrBeg)>2) && (StrBeg[length(StrBeg)-2]!='\\'))   //fix one error when equation end with dollar $
 	 && (StrBeg[length(StrBeg)-1]=='&'))
-		StrBeg=copy(StrBeg,0,length(StrBeg)-1);
+		StrBeg = copy(StrBeg,0,length(StrBeg)-1);
 	//We have all equation contents in the string StrBeg at this point
 
   if(StrBeg == "") return(false);  /*equation is empty-nothing to do*/
@@ -1726,23 +1727,30 @@ void BoxTexFoot(TconvertedPass1 *cq, const TBox & Box)
 string & FixFormulaStrFromTeX(string & StrEnd, const char chr_set)
 {
   if(StrEnd[0] == '$')
-       {
-	StrEnd=copy(StrEnd,1,length(StrEnd)-2);
-	if((("\\Biggl" IN StrEnd || "\\Biggr" IN StrEnd ||
-	     "\\biggl" IN StrEnd || "\\biggr" IN StrEnd ) && length(StrEnd)>6) ||
-	   (("\\Bigl" IN StrEnd || "\\Bigr" IN StrEnd ||
-	     "\\bigl" IN StrEnd || "\\bigr" IN StrEnd ) && length(StrEnd)>5))
+    {
+    StrEnd = copy(StrEnd,1,length(StrEnd)-2);
+    if((("\\Biggl" IN StrEnd || "\\Biggr" IN StrEnd ||
+	 "\\biggl" IN StrEnd || "\\biggr" IN StrEnd ) && length(StrEnd)>6) ||
+	 (("\\Bigl" IN StrEnd || "\\Bigr" IN StrEnd ||
+	  "\\bigl" IN StrEnd || "\\bigr" IN StrEnd ) && length(StrEnd)>5))
 		StrEnd="{"+StrEnd+"}";
-	else StrEnd+=' ';
-       }
-  else {
-	if(chr_set==10)
-          {
-          StrEnd="{\\cyr "+StrEnd+"}";
-          Cyrillic = true;
-          }
-          else StrEnd="{\\rm "+StrEnd+"}";
-       }
+    else StrEnd+=' ';
+    }
+  else 
+    {
+    if(chr_set==10)
+      {
+      StrEnd = "{\\cyr " + StrEnd + "}";
+      Cyrillic = true;
+      }
+    else
+      {
+      if("\\'{" IN StrEnd || "\\v{" IN StrEnd || "\\r{" IN StrEnd)
+        StrEnd = "{" + StrEnd + "}";
+      else
+        StrEnd = "{\\rm " + StrEnd + "}";
+      }
+    }
 
   string StrBeg;
   while(RemoveSymbol(StrBeg, StrEnd, "\\i"))
