@@ -438,21 +438,22 @@ TconvertedPass1 *cq5;
 extern unsigned char CharsWP6_1_32[0x21];
 
 /** Convert a block of WP6.x text into PostScript. */
-static void TextWPG2_2PS(TconvertedPass1 *cq, long ldblk, string & PSData, PS_State *PSS,
+static TextContainer *TextWPG2_2PS(TconvertedPass1 *cq, long ldblk, string & PSData, PS_State &PSS,
 		/* WPG_records *WPG, */
 		float x, float y, float dx, float dy, int Angle)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#TextWPG2_2PS(%ld) ",ldblk);fflush(cq->log);
 #endif
-string Text;
+TextContainer *pTxC;
+//string Text;
 WORD FontSize=1100;
-RGB_Record BkTextColor = PSS->TextColor;
+RGB_Record BkTextColor = PSS.TextColor;
 TconvertedPass1 *cq6;				// Converter for embedded text fragment
 long ActualPos;
 
   cq6 = GetConvertor("WP6.x");
-  if(cq6==NULL) return;
+  if(cq6==NULL) return NULL;
 
   cq->ActualPos = ftell(cq->wpd);
   ldblk+=cq->ActualPos;			//end position
@@ -465,6 +466,11 @@ long ActualPos;
   cq6->ActualPos=cq->ActualPos;
   cq6->flag = Nothing;
 
+  pTxC = new TextContainer();
+  pTxC->PosX = x;
+  pTxC->PosY = y;
+  pTxC->FontOrientation = Angle;
+
   while(cq6->ActualPos<ldblk)
     {
     *cq6->ObjType = 0;
@@ -479,22 +485,8 @@ long ActualPos;
 	if(cq6->subby==0x1B)
 	  {
 	  fseek(cq6->wpd,6+2,SEEK_CUR); //<flags><PIDsNo>[descriptor][NDelSize]
-          if(length(Text)<=0)	// 1st font size change
-            {
-	    Rd_word(cq6->wpd, &FontSize);
-            sprintf(cq6->ObjType,"Font Size %dWPu",FontSize);
-	    }
-          else
-            {
-            WORD FontSize2;
-            Rd_word(cq6->wpd, &FontSize2);
-            if(FontSize2!=FontSize)
-              {
-              Text += ") show\n";
-              Font2PS(PSData,FontSize2/50.0f);
-	      Text += "\n(";
-              }
-            }	  
+          Rd_word(cq6->wpd, &FontSize);
+	  PSS.FontSize = FontSize / (2.66*50);            	  
 	  }
 	}
 
@@ -505,24 +497,14 @@ long ActualPos;
 	  RGB_Record NewColor;
 
 	  fseek(cq6->wpd,3+2,SEEK_CUR);
-	  NewColor.Red=fgetc(cq6->wpd);
-	  NewColor.Green=fgetc(cq6->wpd);
-	  NewColor.Blue=fgetc(cq6->wpd);
+	  NewColor.Red = fgetc(cq6->wpd);
+	  NewColor.Green = fgetc(cq6->wpd);
+	  NewColor.Blue = fgetc(cq6->wpd);
 
-          if(length(Text)<=0)
-            PSS->TextColor = NewColor;
-          else
-            {
-	      if(memcmp(&NewColor,&PSS->TextColor,sizeof(PSS->TextColor)))
-              {              
-	      Text += ") show\n";
-	      Color2PS(Text,NewColor);
-	      Text += " (";
-              }          
-	    }
-
-	  //transparency is ignored
-	  sprintf(cq6->ObjType,"Pen Fore Color %d,%d,%d",PSS->TextColor.Red,PSS->TextColor.Green,PSS->TextColor.Blue);
+          PSS.TextColor = NewColor;
+          
+		//transparency is ignored
+	  sprintf(cq6->ObjType,"Pen Fore Color %d,%d,%d",PSS.TextColor.Red,PSS.TextColor.Green,PSS.TextColor.Blue);
 	  }
 	}
       fseek(cq6->wpd,ActualPos,SEEK_SET);
@@ -534,47 +516,52 @@ long ActualPos;
       WORD WChar;      
       Rd_word(cq->wpd, &WChar);      
       const char *str = Ext_chr_str(WChar, cq6, cq6->ConvertCpg);
-      if(str==NULL)
-        Text += '_';
-      else
-        Text += str;
+      if(str==NULL)        
+	pTxC->AddText("_",PSS);
+      else        
+	pTxC->AddText(str,PSS);        
       fseek(cq6->wpd,ActualPos,SEEK_SET);
       }
 
-    if(cq6->by>0x20 && cq6->by<=0x7F)
+    if(cq6->by>0x20 && cq6->by<=0x7F)	// Normal_char
       {
-      Text += cq6->by;			// Normal_char
+      char By2Str[2] ={cq6->by,0};
+      if(cq6->by==')' || cq6->by=='(') 
+        {        
+        pTxC->AddText("\\",PSS);
+        }
+      pTxC->AddText(By2Str,PSS);
       }
 
     if(cq6->by>=0x01 && cq6->by<=0x20)	// Default extended international characters (from 0)
       {
       const char *str = Ext_chr_str(0x100 | CharsWP6_1_32[cq6->by],cq6,cq6->ConvertCpg);
       if(str==NULL)
-        Text += '_';
+        pTxC->AddText("_",PSS);
       else
-        Text += str;
+	pTxC->AddText(str,PSS);
       }
 
     if(cq6->by==0x80 ||			// Space
        cq6->by==0x81)        		// Hard space       
       {
-      Text += ' ';
+      pTxC->AddText(" ",PSS);
       }
 
     if(cq6->by==0xCC ||			// HRt
        cq6->by==0xC7 ||
        cq6->by==0xD0)			// HRt/Hpg
-      Text += '\n';
-
+      pTxC->AddText("\n",PSS);
 
     cq6->Dispatch(DISP_PROCESSKEY);
     }
   if(cq6!=cq)
 	delete cq6;
 
-  StoreText2PS(PSData,Text, PSS,Angle,
-	       x+dx, y+dy, x, y, FontSize/50.0/2.66);
-  PSS->TextColor = BkTextColor;
+  //StoreText2PS(PSData,Text, PSS,Angle, x+dx, y+dy, x, y, FontSize/50.0/2.66);
+  PSS.TextColor = BkTextColor;
+
+  return pTxC;
 }
 
 
@@ -940,7 +927,8 @@ vecResizeCTM TRx;
     case 0x0F:{//CrackObject(cq,NewObject);
               UpdateBBox(bbx, 0,
 		         WPGu2PSu(ImgSts.x),WPGu2PSu(ImgSts.y),WPGu2PSu(ImgSts.x+ImgSts.dx),WPGu2PSu(ImgSts.y+ImgSts.dy));
-	      TextWPG2_2PS(cq,Rec2.RecordLength,PSData,&PSS,WPGu2PSu(ImgSts.x),WPGu2PSu(ImgSts.y),WPGu2PSu(ImgSts.dx),WPGu2PSu(ImgSts.dy),0);
+	      TextContainer *TxC = TextWPG2_2PS(cq,Rec2.RecordLength,PSData,PSS,WPGu2PSu(ImgSts.x),WPGu2PSu(ImgSts.y),WPGu2PSu(ImgSts.dx),WPGu2PSu(ImgSts.dy),0);
+	      if(TxC!=NULL) VectList.AddObject(TxC);
 	      strcpy(cq->ObjType,"Text Data");
 	      break;
 	      }
