@@ -1141,7 +1141,7 @@ RGB_Record BkTextColor;
           }
         }
 
-        if(i==0 || fabs(Text[i]->size-Text[i-1]->size)>1e-3)
+        if(i==0 || fabs(Text[i]->size-Text[i-1]->size)>1e-3 || Text[i]->TargetFont()!=Text[i-1]->TargetFont())
           str.cat_printf("\n/%s findfont %.2f scalefont setfont",
                          Text[i]->TargetFont(), Text[i]->size*2.66f);
 
@@ -1179,18 +1179,38 @@ void TextContainer::AddText(temp_string contents, const PS_State &PSS)
 {
   const char *PsFontName;  
 
+  //printf("|%s|",contents());
   if(PSS.FontItallic)
     PsFontName = (PSS.FontWeight>=500) ? "Times-BoldItalic" : "Times-Italic";
   else
     PsFontName = (PSS.FontWeight>=500) ? "Times-Bold" : "Times-Roman";
+
+  contents = replacesubstring(contents,"!`","\\241");
+  contents = replacesubstring(contents,"{c}\\llap{/}","\\242");
+  contents = replacesubstring(contents,"\\cent ","\\242");
+  contents = replacesubstring(contents,"\\textcentoldstyle{}","\\242");
+  contents = replacesubstring(contents,"\\pounds{}","\\243");
+  contents = replacesubstring(contents,"\\textyen{}","\\245");
+  contents = replacesubstring(contents,"\\degrees ","\\312");
+  contents = replacesubstring(contents,"\\textdegree{}","\\312");
   
   for(int i=0; i<sizeof(GreekText)/sizeof(char*); i++)
     {
-    if(!StrCmp(contents,GreekText[i]))
-      {      
+    const char *s = StrStr(contents(),GreekText[i]);
+    if(s==NULL) continue;
+    if(s==contents())		// Greek symbol is at the the beginning.
+      {
       AddText(PsText[i], "Symbol", PSS);
-      return;
-      }    
+      contents = copy(contents,strlen(GreekText[i]),contents.length());
+      if(contents.length()<=0) return;
+      continue;
+      }
+    string Begin = copy(contents, 0, s-contents());
+    AddText(Begin, PSS);	// Use recursion for preffix, it could also contain something strange.
+
+    AddText(PsText[i], "Symbol", PSS);
+    contents = copy(contents, strlen(GreekText[i]) + (s-contents()), contents.length());
+    if(contents.length()<=0) return;
     }
   
   AddText(contents, PsFontName, PSS);
@@ -1201,7 +1221,7 @@ void TextContainer::AddText(temp_string contents, const char *font, const PS_Sta
 {
 TextObject *pTobj;
   if(contents.length()<=0) return;
-  
+
   if(Text==NULL || TextObjects<=0)
   {
     Text = (TextObject**)malloc(sizeof(TextObject*));
@@ -1224,7 +1244,7 @@ TextObject *pTobj;
   }
 
   TextObjects++;
-  TextObject** tmp = (TextObject**)realloc(Text, (TextObjects)*sizeof(TextObject*));
+  TextObject **tmp = (TextObject**)realloc(Text, (TextObjects)*sizeof(TextObject*));
   if(tmp==NULL) 
     {	// @TODO - report a memory problem.
     TextObjects--;
@@ -1381,6 +1401,7 @@ const char *pos;
  @param[in] LowLeftX	Boundind box left bottom x boundary in PS units.
  @param[in] LowLeftY	Boundind box left bottom y boundary in PS units.
  @param[in] FontSize	Size of font [mm]. */
+/*
 void StoreText2PS(string & PSData, string & Text, PS_State *PSS, WORD RotAngle,
 		float UpRightX, float UpRightY, float LowLeftX, float LowLeftY,
 		float FontSize)
@@ -1449,7 +1470,7 @@ float AdjY;
     PSData += ")\nshow";
 
   if(RotAngle>0) PSData+="\ngrestore";
-}
+} */
 
 
 /// Emit Postscript command for line type change.
