@@ -2236,7 +2236,7 @@ BadResource:
 static void MakeRef6(TconvertedPass1_WP6 *cq, DWORD & NewPos, char TypeRef)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#MakeRef6() ");fflush(cq->log);
+  fprintf(cq->log,"\n#MakeRef6(NewPos=%u) ",NewPos); fflush(cq->log);
 #endif
   unsigned char OldFlag;
   DWORD end_of_code;
