@@ -28,26 +28,27 @@ int SavePictureEPS(const char *Name, const Image &Img);
 string CutFileName(const char *FullFilename); //from wp2lfuti.cc
 
 
+/// WMF codepages: see this https://docs.microsoft.com/en-us/previous-versions/aa915041(v=msdn.10)?redirectedfrom=MSDN
 typedef  enum  
 { 
-  ANSI_CHARSET = 0x00000000, 
-  DEFAULT_CHARSET = 0x00000001, 
+  ANSI_CHARSET = 0x00000000,		///< 1252 FS_LATIN1 
+  DEFAULT_CHARSET = 0x00000001,
   SYMBOL_CHARSET = 0x00000002, 
   MAC_CHARSET = 0x0000004D, 
-  SHIFTJIS_CHARSET = 0x00000080, 
-  HANGUL_CHARSET = 0x00000081, 
-  JOHAB_CHARSET = 0x00000082, 
-  GB2312_CHARSET = 0x00000086, 
-  CHINESEBIG5_CHARSET = 0x00000088, 
-  GREEK_CHARSET = 0x000000A1, 
-  TURKISH_CHARSET = 0x000000A2, 
+  SHIFTJIS_CHARSET = 0x00000080,	///< cp932 FS_JISJAPAN
+  HANGUL_CHARSET = 0x00000081,		///< cp949 FS_WANSUNG
+  JOHAB_CHARSET = 0x00000082,		///< 1361 FS_JOHAB
+  GB2312_CHARSET = 0x00000086,		///< 936 FS_CHINESESIMP 
+  CHINESEBIG5_CHARSET = 0x00000088,	///< 950 FS_CHINESETRAD
+  GREEK_CHARSET = 0x000000A1,		///< 1253 FS_GREEK
+  TURKISH_CHARSET = 0x000000A2,		///< 1254 FS_TURKISH
   VIETNAMESE_CHARSET = 0x000000A3, 
-  HEBREW_CHARSET = 0x000000B1, 
-  ARABIC_CHARSET = 0x000000B2, 
-  BALTIC_CHARSET = 0x000000BA, 
-  RUSSIAN_CHARSET = 0x000000CC, 
-  THAI_CHARSET = 0x000000DE, 
-  EASTEUROPE_CHARSET = 0x000000EE, 
+  HEBREW_CHARSET = 0x000000B1,		///< cp1255 FS_HEBREW
+  ARABIC_CHARSET = 0x000000B2,		///< cp1256 FS_ARABIC
+  BALTIC_CHARSET = 0x000000BA,		///< cp1257 FS_BALTIC 
+  RUSSIAN_CHARSET = 0x000000CC,		///< cp1251 FS_CYRILLIC
+  THAI_CHARSET = 0x000000DE,		///< cp874 FS_THAI
+  EASTEUROPE_CHARSET = 0x000000EE,	///< cp1250 FS_LATIN2
   OEM_CHARSET = 0x000000FF 
 } TCharacterSet;
 
@@ -527,11 +528,16 @@ BYTE Underline, Strikeout, Charset, OutPrecision, ClipPrecision, Quality, PitchA
   switch(Charset)
   {
     case OEM_CHARSET:
-    case ANSI_CHARSET:		
     case DEFAULT_CHARSET:	ConvertCpg = NULL;
 				break;
+    case ANSI_CHARSET:		ConvertCpg = GetTranslator("cp1252TOinternal");
+				break;
     case SYMBOL_CHARSET:        ConvertCpg = GetTranslator("symbolTOinternal");
 				break;
+    case EASTEUROPE_CHARSET:    ConvertCpg = GetTranslator("cp1250TOinternal"); // see https://stackoverflow.com/questions/22911186/windows-encoding-clarification
+				break;
+    case RUSSIAN_CHARSET:	ConvertCpg = GetTranslator("cp1251TOinternal");
+				break;
     case MAC_CHARSET:
     case SHIFTJIS_CHARSET:
     case HANGUL_CHARSET:
@@ -543,10 +549,9 @@ BYTE Underline, Strikeout, Charset, OutPrecision, ClipPrecision, Quality, PitchA
     case VIETNAMESE_CHARSET:
     case HEBREW_CHARSET:
     case ARABIC_CHARSET:
-    case BALTIC_CHARSET:
-    case RUSSIAN_CHARSET:
+    case BALTIC_CHARSET:    
     case THAI_CHARSET:
-    case EASTEUROPE_CHARSET:    
+
     default: if(err!=NULL)
                {
                perc.Hide();
@@ -1182,7 +1187,7 @@ unsigned char c;
     if(ConvertCpg != NULL)
       {
       if(!strcmp(ConvertCpg->Name,"symbolTOinternal"))
-        pTextCont->AddText((char)c, "Symbol", PSS);
+        pTextCont->AddText((char)c, "Symbol", PSS);	// Push Symbol code page without any change.
       else
         {
         const char *str = Ext_chr_str(c, this, ConvertCpg);
@@ -1205,7 +1210,7 @@ unsigned char c;
       pTextCont->AddText((char)c,PSS);
       }
     }
-	  if(pTextCont->isEmpty())    
+  if(pTextCont->isEmpty())    
     delete pTextCont;    
   else    
     VectList.AddObject(pTextCont);    
