@@ -140,7 +140,7 @@ list UserLists;
 
 long  num_of_lines_stripfile,
       UnknownCharacters,UnknownObjects,CorruptedObjects;
-char** UserWPCharSet=NULL;
+CpTranslator *UserWPCharSet=NULL;
 
 string wpd_filename, strip_filename, table_filename, latex_filename,
        log_filename;
@@ -365,11 +365,11 @@ while(!feof(F))
    fGets2(F,s);
    s.trim();
    if(s=="") continue;
-   if(s=="[WPUserChars]")
+/*   if(s=="[WPUserChars]")
 	{
 	Section=1;
 	continue;
-	}
+	} */
    if(s=="[Fonts]")
 	{
 	Section=2;
@@ -379,7 +379,7 @@ while(!feof(F))
    switch(Section)
 	{
 	case 0:break;
-	case 1:if(sscanf(s(),"%d",&i)!=1) break;
+/*	case 1:if(sscanf(s(),"%d",&i)!=1) break;
 	       if(i<0 || i>255) break;
 	       while(isdigit(s[0]))
 		   {
@@ -389,14 +389,14 @@ while(!feof(F))
 	       s=trim(s);
 	       if(UserWPCharSet==NULL)
 		   {
-		   UserWPCharSet=(char **)calloc(255,sizeof(char *));
+		   UserWPCharSet = (char**)calloc(256,sizeof(char *));
 		   if(UserWPCharSet==NULL) break;
-		   memset(UserWPCharSet,0,255*sizeof(char *));
+		   memset(UserWPCharSet,0,256*sizeof(char *));
 		   }
 
 	       if(UserWPCharSet[i]!=NULL) free(UserWPCharSet[i]);
 	       UserWPCharSet[i]=strdup(s());
-	       break;
+	       break; */
 	case 2:FontTable+=s;
 	       break;
 	}
@@ -1425,6 +1425,20 @@ void PrintPackageList(void)
 }
 
 
+const OutCodePage OutCodepages[11] =
+{
+	{"852", 852},
+	{"866", 866},
+	{"895", 895},
+	{"1250",1250},
+	{"1251",1251},
+	{"ISO8859-1", ISO8859_1},	{"ISO-8859-1", ISO8859_1},
+	{"ISO8859-2", ISO8859_2},	{"ISO-8859-2", ISO8859_2},
+	{"KOI8R", KOI8R},
+	{"UTF8", UTF8}
+};
+
+
 /** This procedure handles parameters and the filenames*/
 int CommandLine(int argc, char *argv[])
 {
@@ -1471,61 +1485,25 @@ int p;
 	   RunError(-2); return(0);
 	   }
 
-      if(!strncmp(name, "cp",3))
+      if(!strncmp(name, "cp",2))
 	  {
 	  name += 2;
 	  if(*name=='-') name++;
-	  if(!strcmp(name, "852"))
-	      {
-	      CodePage = 852;
-	      continue;
-	      }
-          if(!strcmp(name, "866"))
-	      {
-	      CodePage = 866;
-	      continue;
-	      }
-	   		  
-	  if(!strcmp(name, "895"))
-	      {
-	      CodePage = 895;
-	      continue;
-	      }
-	  if(!strcmp(name, "1250"))
-	      {
-	      CodePage = 1250;
-	      continue;
-	      }
-	  if(!strcmp(name, "1251"))
-	      {
-	      CodePage = 1251;
-	      continue;
-	      }
-	  
-	  if(!strcmp(name, "ISO8859-1") || !strcmp(name, "ISO-8859-1"))
-	      {
-	      CodePage = ISO8859_1;
-	      continue;
-	      }
-	  if(!strcmp(name, "ISO8859-2") || !strcmp(name, "ISO-8859-2"))
-	      {
-	      CodePage = ISO8859_2;
-	      continue;
-	      }
 
-	  if(!strcmp(name, "KOI8R"))
+          for(i=0; i<sizeof(OutCodepages)/sizeof(OutCodePage); i++)
 	      {
-	      CodePage = KOI8R;
-	      continue;
-	      }
-
-	  if(!strcmp(name, "UTF8"))
-	      {
-	      CodePage = UTF8;
-              CPStyles = true;
-              Convert2Target = GetTranslator("internalTOunicode");
-	      continue;
+              if(!strcmp(name, OutCodepages[i].Name))
+	        {
+	        CodePage = OutCodepages[i].Id;
+	        if(CodePage==UTF8)
+		  {
+                  CPStyles = true;
+                  Convert2Target = GetTranslator("internalTOunicode");
+		  }
+                break;	      
+                }
 	      }
+          if(i<=sizeof(OutCodepages)/sizeof(OutCodePage)) continue;	// Output codepage has been found.
 	  
 	  if(!strcmp(name, "Styles") || !strcmp(name, "styles"))
 	     {
@@ -1554,6 +1532,23 @@ int p;
 	  SaveWPG = 1;
 	  continue;
 	  }
+
+      if(!strcmp(name, "CurrentFontSet"))
+	  {
+	  if(CheckArg(p,argc,argv[p]))
+	    {
+	    string CFSconvertor(argv[p]);
+            CFSconvertor += "TOinternal";
+            UserWPCharSet = GetTranslator(CFSconvertor());
+	    if(UserWPCharSet==NULL)
+	      {
+	      if(err!=NULL)
+                fprintf(err,_("Warning, cannot get code page translator \"%s\"."), CFSconvertor());
+	      }
+	    }
+	  continue;
+	  }
+
       if(!strcmp(name, "fig-output-dir")||!strcmp(name, "figoutputdir"))
 	  {
 	  if(CheckArg(p,argc,argv[p]))
